##############################################################################
#
# Copyright (c) 2004-2012 Zope Foundation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Unit tests for the testrunner's handling of non-unique test IDs."""


import unittest

from zope.testing import doctest
from zope.testing.testrunner.find import (
    DuplicateTestIDError,
    tests_from_suite,
    )


class UniquenessTestCase(unittest.TestCase):
    """A test case to test how the testrunner handles non-unique IDs."""

    def test_tests_from_suite_raises_if_duplicate_id_found(self):
        # If tests_from_suite() encounters a test ID which has already
        # been registered, it will complain.
        suites = [
            doctest.DocFileSuite('testrunner-ex/sampletests.txt'),
            doctest.DocFileSuite('testrunner-ex/sampletests.txt'),
            ]
        # We define some basic options here to keep tests_from_suite
        # happy.
        class Options:
            keepbytecode = True
            at_level = 99
            test = []
        test_suites = unittest.TestSuite(suites)
        # We have to wrap this in a function as tests_from_suite()
        # returns a generator, so the error won't be triggered until we
        # actually try to iterate over the results.
        def get_tests():
            return [
                test for test in tests_from_suite(test_suites, Options())]
        self.assertRaises(DuplicateTestIDError, get_tests)
